@@ -3,6 +3,7 @@ from .training_set_admin import TrainingSetAdmin
 from .document_admin import DocumentAdmin
 from .group_api_key_admin import GroupAPIKeyAdmin
 from .feedback_admin import FeedbackAdmin
+from .sponsor_admin import SponsorAdmin
 
 __all__ = [
     "DisciplineAdmin",
@@ -10,4 +11,5 @@ __all__ = [
     "DocumentAdmin",
     "GroupAPIKeyAdmin",
     "FeedbackAdmin",
+    "SponsorAdmin",
 ]
